###########################################################################/**
# @RdocDocumentation toNNN
# @alias toBMP
# @alias toEMF
# @alias toEPS
# @alias toPDF
# %% @alias toCairoPNG
# @alias toPNG
# @alias toSVG
# @alias toTIFF
# @alias toWMF
# @alias toFavicon
# @alias asDataURI
#
# % Interactive/screen devices
# @alias toDefault
# @alias toQuartz
# @alias toWindows
# @alias toX11
# @alias toCairoWin
# @alias toCairoX11
# %% @alias toJavaGD
#
# @title "Methods for creating image files of a specific format"
#
# \description{
#  @get "title".
# }
#
# \usage{
#   toBMP(name, ..., field=getOption("devEval/args/field", "pathname"))
#   toEMF(name, ..., ext="emf", field=getOption("devEval/args/field", "pathname"))
#   toPDF(name, ..., field=getOption("devEval/args/field", "pathname"))
#   toPNG(name, ..., field=getOption("devEval/args/field", "pathname"))
#   toSVG(name, ..., field=getOption("devEval/args/field", "pathname"))
#   toTIFF(name, ..., field=getOption("devEval/args/field", "pathname"))
#   toWMF(name, ..., ext="wmf", field=getOption("devEval/args/field", "pathname"))
#   %% toCairoPNG(name, ..., field=getOption("devEval/args/field", "pathname"))
#
#   toFavicon(..., name="favicon", type="png", width=32L, height=width,
#                  par=list(mar=c(0,0,0,0), bg="transparent"))
#
#   % Interactive/screen devices
#   toDefault(name, ...)
#   toQuartz(name, ...)
#   toX11(name, ...)
#   toWindows(name, ...)
#
#   % Interactive/screen devices from other packages
#   toCairoWin(name, ...)
#   toCairoX11(name, ...)
#   %% toJavaGD(name, ...)
# }
#
# \arguments{
#   \item{name}{A @character string specifying the name of the image file.}
#   \item{...}{Additional arguments passed to @see "devEval", e.g.
#      \code{tags} and \code{aspectRatio}.}
#   \item{ext}{A @character string specifying the filename extension.}
#   \item{field}{Passed to @see "devEval".}
#   \item{width, height, type, par}{Passed to @see "devEval".}
# }
#
# \value{
#   Returns by default the so called \emph{fullname} of the generated
#   image file.  The fullname of an file is the filename without the
#   extension.
# }
#
# @author
#
# \seealso{
#   These functions are wrappers for @see "devEval".
#   See @see "devOptions" to change the default dimensions for
#   a specific device type.
# }
#
# @keyword device
# @keyword utilities
#*/###########################################################################
toBMP <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="bmp", name=name, ..., field=field);
}

toEMF <- function(name, ..., ext="emf", field=getOption("devEval/args/field", "pathname")) {
  devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
}

toWMF <- function(name, ..., ext="wmf", field=getOption("devEval/args/field", "pathname")) {
  devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
}

toEPS <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="eps", name=name, ..., field=field);
}

toPDF <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="pdf", name=name, ..., field=field);
}

toPNG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="png", name=name, ..., field=field);
}

toSVG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="svg", name=name, ..., field=field);
}

toTIFF <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
  devEval(type="tiff", name=name, ..., field=field);
}

## toCairoPNG <- function(name, ..., field=getOption("devEval/args/field", "pathname")) {
##   devEval(type="CairoPNG", name=name, ..., field=field);
## }


toFavicon <- function(..., name="favicon", type="png", width=32L, height=width, par=list(mar=c(0,0,0,0), bg="transparent")) {
  # png() will generate a warning that "width=.. , height=.., are unlikely
  # values in pixels" if width < 20.
  suppressWarnings({
    devEval(type=type, name=name, width=width, height=height, par=par, ...);
  })
}

asDataURI <- function(..., mime=NULL) {
  img <- DevEvalFileProduct(...);
  if (is.null(mime)) {
    mime <- getMimeType(img);
  }
  getDataURI(img, mime=mime);
}


toDefault <- function(name, ...) {
  devEval(type=getOption("device"), name=name, ...);
}

toQuartz <- function(name, ...) {
  devEval(type="quartz", name=name, ...);
}

toWindows <- function(name, ...) {
  devEval(type="windows", name=name, ...);
}

toX11 <- function(name, ...) {
  devEval(type="X11", name=name, ...);
}

toCairoWin <- function(name, ...) {
  devEval(type="CairoWin", name=name, ...);
}

toCairoX11 <- function(name, ...) {
  devEval(type="CairoX11", name=name, ...);
}

## toJavaGD <- function(name, ...) {
##   devEval(type="JavaGD", name=name, ...);
## }





##############################################################################
# HISTORY:
# 2014-08-29
# o Changed default argument 'field' for toNNN() from "fullname" to
#   "pathname" as in getOption("devEval/args/field", "pathname").
#   This should work for most compilers include LaTeX, although in
#   later it is preferred to use "fullname".
# 2014-04-28
# o Waiting with toCairoPNG() and toJavaGD().
# o Added toDefault(), toX11(), toWindows(), and toQuartz().
#   Also added toCairoWin() and toCairoX11() for the 'Cairo' package.
# 2014-01-11
# o Added asDataURI().
# 2014-01-10
# o Added toFavicon().
# 2013-07-24
# o Added toEMF()/toWMF().
# 2013-02-23
# o Changed default argument 'field' for toNNN() from "fullname"
#   to getOption("devEval/args/field", "fullname").
# 2012-05-01
# o Renamed Rd to toNNN.
# 2012-04-27
# o Renamed Rd to toPNG().
# 2012-04-07
# o Added toBMP() and toTIFF().
# 2011-11-05
# o Added toSVG().
# o Moved from private R.rsp.addons package to R.utils.
# o Dropped default 'width' from toPNG(), toPDF() and toEPS().  No longer
#   required from R.utils v1.9.1.
# 2011-10-31
# o CLEANUP: toPNG() etc now utilizes new 'field' argument of devEval().
# 2011-09-12
# o Added toEPS().
# 2011-06-15
# o Added argument 'field' to toPNG() and toPDF().
# 2011-05-23
# o Added toPNG() and toPDF().
##############################################################################
